@@ -1,4 +1,4 @@
-# $Id: Vregs.pm,v 1.76 2001/11/26 15:31:41 wsnyder Exp $
+# $Id: Vregs.pm,v 1.82 2002/03/11 15:53:27 wsnyder Exp $
 # Author: Wilson Snyder <wsnyder@wsnyder.org>
 ######################################################################
 #
@@ -34,7 +34,7 @@ use Carp;
 use vars qw($Debug $Bit_Access_Regexp @ISA $VERSION);
 @ISA = qw (SystemC::Vregs::Subclass);	# In Vregs:: so we can get Vregs->warn()
 
-$VERSION = '1.200';
+$VERSION = '1.210';
 
 ######################################################################
 #### Constants
@@ -404,6 +404,25 @@ sub new_register {
 	    defined $acc_col or  return $self->warn ($flagref, "Table is missing column headed 'Access'\n");
 	}
 
+	# Table by table, allow the field mnemonics to be either 'fooFlag'
+	# (per our Coding Conventions) or 'FooFlag' (as in a Vregs ASCII file).
+
+	my $allMnems_LCFirst = (@bittable > 1);
+	foreach my $row (@bittable) {
+	    next if $row eq $bittable[0];	# Ignore header
+	    my $bit_mnem = $row->[$mnem_col] or next;
+	    my $c1 = substr($bit_mnem, 0, 1);
+	    if ($c1 ge 'A' && $c1 le 'Z') { $allMnems_LCFirst = 0; }
+	}
+	if ($allMnems_LCFirst) {
+	    print "  Upcasing first letter of mnemonics.\n" if $Debug;
+	    foreach my $row (@bittable) {
+		next if $row eq $bittable[0];	# Ignore header
+		my $bit_mnem = $row->[$mnem_col] or next;
+		$row->[$mnem_col] = ucfirst $bit_mnem;
+	    }
+	}
+
 	foreach my $row (@bittable) {
 	    print "  Row:\n" if $Debug;
 	    foreach my $col (@$row) {
@@ -730,6 +749,32 @@ sub _valid_mask {
 sub SystemC::Vregs::Type::_create_defines {
     my $typeref = shift;
 
+    # Make size alias
+    (my $nor_mnem  = $typeref->{name}) =~ s/^R_//;
+    new_push SystemC::Vregs::Define::Value
+	(pack => $typeref->{pack},
+	 name => "CSIZE_".$nor_mnem,
+	 rst_val  => $typeref->{words}*4,
+	 is_verilog => 1,	# In C++ use Class::SIZE
+	 is_perl => 1,
+	 desc => "Class Size", );
+
+    if ($typeref->{name} =~ /^R_/) {
+	my $wr_mask = 0;
+	for (my $bit=0; $bit<$typeref->{pack}->{data_bits}; $bit++) {
+	    my $bitent = $typeref->{bitarray}[$bit];
+	    next if !$bitent;
+	    $wr_mask  |= (1<<$bit) if ($bitent->{write});
+	}
+	new_push SystemC::Vregs::Define::Value
+	    (pack => $typeref->{pack},
+	     name => "CM_".$nor_mnem."_WRITABLE",
+	     rst_val  => sprintf("%08X",$wr_mask,),
+	     bits=>$typeref->{pack}->{data_bits},
+	     is_verilog => 1,	# In C++ use Class::BITMASK_WRITABLE
+	     desc => "Writable mask", );
+    }
+
     # Make bit alias
     foreach my $bitref (values %{$typeref->{fields}}) {
 	{   # Wide-word defines
@@ -1016,7 +1061,7 @@ sub regs_write {
 
     my $fh = IO::File->new(">$filename") or croak "%Error: $! $filename.";
 
-    print $fh "// DESCR"."IPTION: Register Layout: Generated by vregs\n";
+    print $fh "// DESCR"."IPTION: Register Layout: Generated AUTOMATICALLY by vregs\n";
     print $fh "//\n";
     print $fh "// Format:\n";
     print $fh "//\tpackage {name}\n";
